@@ -1,7 +1,7 @@
 import logging
 
 from .beatsaver import BeatSaver
-from .beatsaverapi import BeatSaverAPI
+from .beatsaver_api import BeatSaverAPI
 from .beatsaver_provider import BeatSaverProvider
 from .errors import *
 from .models import *
